@@ -3,7 +3,7 @@ context("cross")
 test_that("long format corresponds to expand.grid output", {
   x <- list(a = 1:3, b = 4:9)
 
-  out1 <- cross_d(x)
+  out1 <- cross_df(x)
   out2 <- expand.grid(x, KEEP.OUT.ATTRS = FALSE) %>% dplyr::as_data_frame()
 
   expect_equal(out1, out2)
@@ -15,7 +15,12 @@ test_that("filtering works", {
   expect_equal(out, list(list(1, 2), list(1, 3), list(2, 3)))
 })
 
+test_that("filtering fails when filter function doesn't return a logical", {
+  filter <- function(x, y, z) x + y + z
+  expect_error(cross3(1:3, 1:3, 1:3, .filter = filter))
+})
+
 test_that("works with empty input", {
-  expect_equal(cross_n(list()), list())
-  expect_equal(cross_n(NULL), NULL)
+  expect_equal(cross(list()), list())
+  expect_equal(cross(NULL), NULL)
 })
